package com.elab.mongodb.config;

import com.elab.mongodb.MongoHelper;
import com.elab.mongodb.chain.CatMongoInterceptInvoke;
import com.elab.mongodb.chain.MongoInterceptInvoke;
import com.elab.mongodb.config.property.MongoConfig;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.EnableAspectJAutoProxy;
import org.springframework.data.mongodb.core.MongoTemplate;

import java.net.UnknownHostException;
import java.util.List;

/**
 * 监控目标:
 * - 执行语句
 * - 执行耗时
 * - 结果内容
 *
 * @author liuhx
 * @create 2019/06/06 11:31
 * @email liuhx@elab-plus.com
 **/
@Configuration
@EnableAspectJAutoProxy
@EnableConfigurationProperties(value = {MongoConfig.class})
public class MongoAutoConfiguration {
    @Bean
    public MongoInterceptInvoke catMongoInterceptInvoke() {
        return new CatMongoInterceptInvoke();
    }

    @Bean
    @ConditionalOnMissingBean(value = {MongoTemplate.class})
    public MongoTemplate mongoTemplate(
        @Autowired
            MongoConfig mongoConfig,
        @Autowired(required = false)
            List<MongoInterceptInvoke> mongoInterceptInvokeList) throws UnknownHostException {
        return MongoHelper.newMongoTemplate(mongoConfig, mongoInterceptInvokeList);
    }

}
