package com.elab.mongodb.config;

import com.elab.mongodb.MongoHelper;
import com.elab.mongodb.chain.MongoInterceptInvoke;
import com.elab.mongodb.config.property.MongoConfig;
import com.elab.mongodb.config.property.MultipleMongoProperties;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.net.UnknownHostException;
import java.util.List;
import java.util.Map;

/**
 * 多mongo实例自动配置
 *
 * @author liukaixiong
 * @date 2022/10/10 - 10:40
 */
@Configuration
@EnableConfigurationProperties(value = {MultipleMongoProperties.class})
public class MongoMultipleAutoConfiguration {

    @Autowired(required = false)
    private List<MongoInterceptInvoke> mongoInterceptInvokeList;

    @Bean
    public MongoSelector mongoSelector(MultipleMongoProperties properties) {

        final MongoSelector instance = MongoSelector.getInstance();

        final Map<String, MongoConfig> groupSource = properties.getGroupSource();
        groupSource.forEach((k, v) -> {
            try {
                instance.add(k, MongoHelper.newMongoTemplate(v, mongoInterceptInvokeList));
            } catch (UnknownHostException e) {
                e.printStackTrace();
            }
        });
        return instance;
    }

}
