package com.elab.mongodb.config;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.util.Assert;

import java.util.HashMap;
import java.util.Map;

/**
 * mongo选择器
 *
 * @author liukaixiong
 * @date 2022/10/10 - 10:44
 */
public class MongoSelector {
    private static final MongoSelector INSTANCE = new MongoSelector();
    private final Logger logger = LoggerFactory.getLogger(getClass());
    private final Map<String, MongoTemplate> selector = new HashMap<>();

    public static MongoSelector getInstance() {
        return INSTANCE;
    }

    /**
     * 选择对应的key
     *
     * @param name db的key
     * @return
     */
    public static MongoTemplate selectKey(String name) {
        return getInstance().get(name);
    }

    /**
     * 添加对应的key
     *
     * @param name
     * @param mongoTemplate
     */
    protected void add(String name, MongoTemplate mongoTemplate) {
        Assert.notNull(name, "name 不能为空!");
        Assert.notNull(mongoTemplate, "mongoTemplate 不能为空!");

        selector.put(name, mongoTemplate);
        logger.info("mongo新增[{}]连接, mongoDBName:{}", name, mongoTemplate.getDb().getName());
    }

    /**
     * 获取对应的key的连接
     *
     * @param name
     * @return
     */
    public MongoTemplate get(String name) {
        final MongoTemplate mongoTemplate = selector.get(name);
        Assert.notNull(mongoTemplate, "没有找到[" + name + "]相关的mongo数据源,请检查[spring.elab.mongodb.group-source]是否定义!");
        return mongoTemplate;
    }

}
